# hypervector-wrapper

![workflow](https://github.com/hypervectorio/hypervector-wrapper/actions/workflows/main.yml/badge.svg)
[![PyPI version](https://badge.fury.io/py/hypervector-wrapper.svg)](https://pypi.python.org/pypi/hypervector-wrapper/)

Python wrapper to access the Hypervector API, providing easy deserialisation of Hypervector
resources to Python objects for building your data-driven test suite.

## Docs

Full API and wrapper docs are available at [https://docs.hypervector.io](https://docs.hypervector.io), along with
release history and usage examples.

## Installation

```python
pip install hypervector-wrapper
```

Note: requires Python 3.6+

You can install the development dependencies and run tests with:

```python
pip install -e ".[dev]"
pytest
```